@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : autogen.sh
-# Version    : $Id: autogen.sh,v 1.37 2014/05/10 12:34:32 ds6peter Exp $
+# Version    : $Id: autogen.sh,v 1.43 2014/07/13 10:28:05 ds6peter Exp $
 # Copyright  : 2003-2014 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information: autogeneration of projects with optional features
@@ -21,26 +21,32 @@ while [ "$1" != "$LAST" ]; do
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-geoip --enable-ip2location"
 		SKIP_STATIC=1
+		use_geoip=1
+		use_ip2location=1
 		;;
 	    '--geoip'|'-g')
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-geoip"
 		SKIP_STATIC=1
+		use_geoip=1
 		;;
 	    '--geoip-dyn'|'-G')
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-geoip --with-geoip-dynamic"
 		SKIP_STATIC=1
+		use_geoip=1
 		;;
 	    '--ip2location'|'-i')
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-ip2location"
 		SKIP_STATIC=1
+		use_ip2location=1
 		;;
 	    '--ip2location-dyn'|'-I')
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-ip2location --with-ip2location-dynamic"
 		SKIP_STATIC=1
+		use_ip2location=1
 		;;
 	    '--disable-db-ieee')
 		shift
@@ -68,27 +74,18 @@ while [ "$1" != "$LAST" ]; do
 		shift
 		SKIP_STATIC=1
 		;;
+	    '--no-test')
+		shift
+		SKIP_TEST=1
+		;;
 	    '--enable-bundled-md5'|'--enable-bundled-getopt')
 		# whitelisted
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE $1"
 		shift
 		;;
-	    '-W')
-		shift
-		EXTRA_CFLAGS="-Wformat"
-		gcc_date=$(gcc -v 2>&1 | grep -i version | sed 's/.*\s\([0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]\)\s.*/\1/g')
-		if [ -n "$gcc_date" ]; then
-			if [ $gcc_date -gt 20080704 ]; then
-				# > CentOS/RHEL 5
-				EXTRA_CFLAGS="$EXTRA_CFLAGS -Werror -Werror=format-security"
-			fi
-		fi
-		echo "INFO  : option -W enables EXTRA_CFLAGS=$EXTRA_CFLAGS"
-		;;
 	    '-?'|'-h'|'--help')
 		echo "Supported options:"
 		echo "   -?|-h|--help        : this help"
-		echo "   -W                  : use extra CFLAGS=-Werror"
 		echo "   -n|--no-make        : stop before running 'make'"
 		echo "   -a|--all            : enable GeoIP and IP2Location support"
 		echo "   -g|--geoip          : enable GeoIP support"
@@ -100,11 +97,22 @@ while [ "$1" != "$LAST" ]; do
 		echo "   --disable-db-ipv6   : disable built-in IPv6 database"
 		echo "   --geoip-ipv6-compat : enable GeoIP IPv6 compatibility mode"
 		echo "   -S                  : enable shared library mode"
-		echo "   -no-static-build    : skip static build"
+		echo "   --no-static-build   : skip static build"
+		echo "   --no-test           : skip 'make test'"
 		exit 1
 	esac
 done
 
+source ./autogen-support.sh "source"
+
+if [ "$use_geoip" = "1" ]; then
+	OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE $(fallback_options_from_name GeoIP)"
+fi
+
+if [ "$use_ip2location" = "1" ]; then
+	OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE $(fallback_options_from_name IP2Location)"
+fi
+
 if [ -f Makefile ]; then
 	echo "*** cleanup"
 	make autoclean
@@ -128,10 +136,18 @@ fi
 echo "*** run: make clean"
 make clean || exit 1
 
-export EXTRA_CFLAGS
+if [ "$SKIP_TEST" = "1" ]; then
+	echo "*** skip: make test"
+else
+	echo "*** run: make test"
+	make test || exit 1
+fi
 
-echo "*** run: make test"
-make test || exit 1
+if [ "$SKIP_STATIC" != "1" -a ! -e /etc/redhat-release ]; then
+	# skip static on non Fedora/RedHat/CentOS systems
+	SKIP_STATIC="1"
+	echo "NOTICE: 'make static' skipped on non Fedora/RedHat/CentOS systems"
+fi
 
 if [ "$SKIP_STATIC" != "1" ]; then
 	echo "*** run: make static"
