@@ -1,15 +1,15 @@
 /*
  * Project       : ipv6calc
  * File          : dbieee_oui36.h
- * Version       : $Id: dbieee_oui36.h,v 1.14 2014/05/16 20:34:02 ds6peter Exp $
- * Generated     : Fri May 16 22:13:35 2014
+ * Version       : $Id: dbieee_oui36.h,v 1.15 2014/07/14 06:20:02 ds6peter Exp $
+ * Generated     : Mon Jul 14 08:12:47 2014
  * Data copyright: IEEE
  *
  * Information:
  *  Additional header file for libipv6calc_db_wrapper_BuiltIn.c
  */
 
-/*@unused@*/ static const char* libieee_oui36_status __attribute__ ((__unused__)) = "OUI36/20140516";
+/*@unused@*/ static const char* libieee_oui36_status __attribute__ ((__unused__)) = "OUI36/20140714";
 
 
 static const s_ieee_oui36 libieee_oui36[] = {
@@ -215,22 +215,39 @@ static const s_ieee_oui36 libieee_oui36[] = {
 	{ 0x001BC5, 0x0C8000, 0x0C8FFF, "Dialine", "DIALINE" },
 	{ 0x001BC5, 0x0C9000, 0x0C9FFF, "UAB Kitron", "UAB-KITRON" },
 	{ 0x70B3D5, 0xFFE000, 0xFFEFFF, "PRIVATE", "PRIVATE" },
+	{ 0x70B3D5, 0x062000, 0x062FFF, "RM Michaelides Software & Elektronik GmbH", "RM-MICHAELIDES-SOFTWARE-ELEKTRONIK" },
 	{ 0x70B3D5, 0xFFF000, 0xFFFFFF, "PRIVATE", "PRIVATE" },
+	{ 0x70B3D5, 0xE58000, 0xE58FFF, "Thurlby Thandar Instruments LTD", "THURLBY-THANDAR-INSTRUMENTS" },
 	{ 0x70B3D5, 0xD9E000, 0xD9EFFF, "GRUPO EPELSA S.L.", "GRUPO-EPELSA-S-L" },
+	{ 0x70B3D5, 0xCE7000, 0xCE7FFF, "June Automation Singapore Pte. Ltd.", "JUNE-AUTOMATION-SINGAPORE-PTE" },
 	{ 0x70B3D5, 0x3DE000, 0x3DEFFF, "ELOMAC Elektronik GmbH", "ELOMAC-ELEKTRONIK" },
+	{ 0x70B3D5, 0x182000, 0x182FFF, "Kitron UAB", "KITRON-UAB" },
 	{ 0x70B3D5, 0xB3D000, 0xB3DFFF, "Inras GmbH", "INRAS" },
+	{ 0x70B3D5, 0x6F3000, 0x6F3FFF, "iungo", "IUNGO" },
 	{ 0x70B3D5, 0xEDC000, 0xEDCFFF, "J.D. Koftinoff Software, Ltd.", "J-D-KOFTINOFF-SOFTWARE" },
+	{ 0x70B3D5, 0x5EA000, 0x5EAFFF, "KYS,INC", "KYS" },
 	{ 0x70B3D5, 0xEF9000, 0xEF9FFF, "Critical Link", "CRITICAL-LINK" },
+	{ 0x70B3D5, 0xC61000, 0xC61FFF, "JC HUNTER TECHNOLOGIES", "JC-HUNTER-TECHNOLOGIES" },
 	{ 0x70B3D5, 0xEDD000, 0xEDDFFF, "Solar Network & Partners", "SOLAR-NETWORK-PARTNERS" },
+	{ 0x70B3D5, 0x48D000, 0x48DFFF, "OMEGA BILANCE SRL SOCIETA' UNIPERSONALE", "OMEGA-BILANCE-SRL-SOCIETA-UNIPERSONALE" },
 	{ 0x70B3D5, 0xF62000, 0xF62FFF, "FRS GmbH & Co. KG", "FRS" },
+	{ 0x70B3D5, 0xB82000, 0xB82FFF, "Lookout Portable Security", "LOOKOUT-PORTABLE-SECURITY" },
 	{ 0x70B3D5, 0x0A9000, 0x0A9FFF, "ProConnections, Inc.", "PROCONNECTIONS" },
+	{ 0x70B3D5, 0x220000, 0x220FFF, "PRIVATE", "PRIVATE" },
 	{ 0x70B3D5, 0x3ED000, 0x3EDFFF, "Ultra Electronics Sonar System Division", "ULTRA-ELECTRONICS-SONAR-SYSTEM-DIVISION" },
+	{ 0x70B3D5, 0xE28000, 0xE28FFF, "iotec GmbH", "IOTEC" },
 	{ 0x70B3D5, 0x3C2000, 0x3C2FFF, "Cellular Specialties, Inc.", "CELLULAR-SPECIALTIES" },
+	{ 0x70B3D5, 0xA5B000, 0xA5BFFF, "Christ Elektronik GmbH", "CHRIST-ELEKTRONIK" },
 	{ 0x70B3D5, 0xD8B000, 0xD8BFFF, "Lenoxi Automation s.r.o.", "LENOXI-AUTOMATION-S-R-O" },
+	{ 0x70B3D5, 0x39A000, 0x39AFFF, "Videotrend srl", "VIDEOTREND-SRL" },
 	{ 0x70B3D5, 0xF63000, 0xF63FFF, "Ars Products", "ARS-PRODUCTS" },
+	{ 0x70B3D5, 0x104000, 0x104FFF, "Plum sp. z o.o", "PLUM-SP-Z-O-O" },
 	{ 0x70B3D5, 0x0AA000, 0x0AAFFF, "Wanco Inc", "WANCO" },
+	{ 0x70B3D5, 0xB8D000, 0xB8DFFF, "JungwooEng Co., Ltd", "JUNGWOOENG" },
 	{ 0x70B3D5, 0x994000, 0x994FFF, "KeFF Networks", "KEFF-NETWORKS" },
+	{ 0x70B3D5, 0xCFF000, 0xCFFFFF, "DTECH Labs, Inc.", "DTECH-LABS" },
 	{ 0x70B3D5, 0x0E0000, 0x0E0FFF, "PLCiS", "PLCIS" },
+	{ 0x70B3D5, 0x959000, 0x959FFF, "Zulex International Co.,Ltd.", "ZULEX" },
 	{ 0x70B3D5, 0xAE9000, 0xAE9FFF, "Cari Electronic", "CARI" },
 	{ 0x70B3D5, 0x6D3000, 0x6D3FFF, "DEUTA-WERKE GmbH", "DEUTA-WERKE" },
 	{ 0x70B3D5, 0x139000, 0x139FFF, "Tunstall A/S", "TUNSTALL-A/S" },
@@ -388,7 +405,7 @@ static const s_ieee_oui36 libieee_oui36[] = {
 	{ 0x70B3D5, 0x6F2000, 0x6F2FFF, "P&C Micro's Pty Ltd", "P-C-MICRO-S-PTY" },
 	{ 0x70B3D5, 0xA15000, 0xA15FFF, "Intercore GmbH", "INTERCORE" },
 	{ 0x70B3D5, 0xBCA000, 0xBCAFFF, "Deymed Diagnostic", "DEYMED-DIAGNOSTIC" },
-	{ 0x70B3D5, 0x362000, 0x362FFF, "Zydex Pty Ltd", "ZYDEX-PTY" },
+	{ 0x70B3D5, 0x362000, 0x362FFF, "Asiga", "ASIGA" },
 	{ 0x70B3D5, 0x54D000, 0x54DFFF, "Qingdao Haitian Weiye Automation Control System Co., Ltd", "QINGDAO-HAITIAN-WEIYE-AUTOMATION-CONTROL-SYSTEM" },
 	{ 0x70B3D5, 0xE26000, 0xE26FFF, "FEITIAN CO.,LTD.", "FEITIAN" },
 	{ 0x70B3D5, 0xE99000, 0xE99FFF, "Advitronics telecom bv", "ADVITRONICS-TELECOM" },
@@ -414,5 +431,61 @@ static const s_ieee_oui36 libieee_oui36[] = {
 	{ 0x70B3D5, 0x986000, 0x986FFF, "Aplex Technology Inc.", "APLEX" },
 	{ 0x70B3D5, 0x3CE000, 0x3CEFFF, "Aditec GmbH", "ADITEC" },
 	{ 0x70B3D5, 0x250000, 0x250FFF, "Datum Electronics Limited", "DATUM-ELECTRONICS" },
+	{ 0x70B3D5, 0x0B3000, 0x0B3FFF, "Reonix Automation", "REONIX-AUTOMATION" },
+	{ 0x70B3D5, 0x682000, 0x682FFF, "Rosslare Enterprises Limited", "ROSSLARE-ENTERPRISES" },
+	{ 0x70B3D5, 0xA57000, 0xA57FFF, "PCSC", "PCSC" },
+	{ 0x70B3D5, 0x058000, 0x058FFF, "Telink Semiconductor CO, Limtied, Taiwan", "TELINK-SEMICONDUCTOR-LIMTIED-TAIWAN" },
+	{ 0x70B3D5, 0xEB2000, 0xEB2FFF, "Shooter Detection Systems", "SHOOTER-DETECTION" },
+	{ 0x70B3D5, 0x709000, 0x709FFF, "AML", "AML" },
+	{ 0x70B3D5, 0x20C000, 0x20CFFF, "Siemens Healthcare Diagnostics", "SIEMENS-HEALTHCARE-DIAGNOSTICS" },
+	{ 0x70B3D5, 0xAA0000, 0xAA0FFF, "Simple Works, Inc.", "SIMPLE-WORKS" },
+	{ 0x70B3D5, 0xA62000, 0xA62FFF, "Environexus", "ENVIRONEXUS" },
+	{ 0x70B3D5, 0x025000, 0x025FFF, "Elsuhd Net Ltd Co.", "ELSUHD-NET" },
+	{ 0x70B3D5, 0x36D000, 0x36DFFF, "Cyberteam Sp z o o", "CYBERTEAM-SP-Z-O-O" },
+	{ 0x70B3D5, 0xCF1000, 0xCF1FFF, "LightDec GmbH & Co. KG", "LIGHTDEC" },
+	{ 0x70B3D5, 0x82C000, 0x82CFFF, "NELS Ltd.", "NELS" },
+	{ 0x70B3D5, 0x941000, 0x941FFF, "Triax A/S", "TRIAX-A/S" },
+	{ 0x70B3D5, 0x55D000, 0x55DFFF, "LunaNexus Inc", "LUNANEXUS" },
+	{ 0x70B3D5, 0x731000, 0x731FFF, "Phoniro Systems AB", "PHONIRO-AB" },
+	{ 0x70B3D5, 0xDF3000, 0xDF3FFF, "SPC Bioclinicum", "SPC-BIOCLINICUM" },
+	{ 0x70B3D5, 0x501000, 0x501FFF, "PEEK TRAFFIC", "PEEK-TRAFFIC" },
+	{ 0x70B3D5, 0x3EF000, 0x3EFFFF, "Vtron Pty Ltd", "VTRON-PTY" },
+	{ 0x70B3D5, 0x3DF000, 0x3DFFFF, "MultiDyne", "MULTIDYNE" },
+	{ 0x70B3D5, 0xBC6000, 0xBC6FFF, "Hatteland Display AS", "HATTELAND-DISPLAY-AS" },
+	{ 0x70B3D5, 0x0C0000, 0x0C0FFF, "Molu Technology Inc., LTD.", "MOLU" },
+	{ 0x70B3D5, 0xAE2000, 0xAE2FFF, "Transas Marine International", "TRANSAS-MARINE" },
+	{ 0x70B3D5, 0x708000, 0x708FFF, "IBM Research GmbH", "IBM-RESEARCH" },
+	{ 0x70B3D5, 0xC43000, 0xC43FFF, "Future Skies", "FUTURE-SKIES" },
+	{ 0x70B3D5, 0xF2B000, 0xF2BFFF, "SENSYS GmbH", "SENSYS" },
+	{ 0x70B3D5, 0xC6D000, 0xC6DFFF, "Cyviz AS", "CYVIZ-AS" },
+	{ 0x70B3D5, 0xDA1000, 0xDA1FFF, "Qprel srl", "QPREL-SRL" },
+	{ 0x70B3D5, 0x85C000, 0x85CFFF, "Robot Pub Group", "ROBOT-PUB-GROUP" },
+	{ 0x70B3D5, 0x22B000, 0x22BFFF, "VITEC", "VITEC" },
+	{ 0x70B3D5, 0x1F5000, 0x1F5FFF, "Martec S.p.A.", "MARTEC-S-P-A" },
+	{ 0x70B3D5, 0xE92000, 0xE92FFF, "FUJI DATA SYSTEM CO.,LTD.", "FUJI-DATA-SYSTEM" },
+	{ 0x70B3D5, 0xF8C000, 0xF8CFFF, "EUROPEAN ADVANCED TECHNOLOGIES", "EUROPEAN-ADVANCED-TECHNOLOGIES" },
+	{ 0x70B3D5, 0x08E000, 0x08EFFF, "Beijing CONvision Technology Co.,Ltd", "BEIJING-CONVISION" },
+	{ 0x70B3D5, 0xBA4000, 0xBA4FFF, "EIWA GIKEN INC.", "EIWA-GIKEN" },
+	{ 0x70B3D5, 0x57C000, 0x57CFFF, "Automata GmbH & Co. KG", "AUTOMATA" },
+	{ 0x70B3D5, 0xD59000, 0xD59FFF, "WyreStorm Technologies", "WYRESTORM-TECHNOLOGIES" },
+	{ 0x70B3D5, 0x6D6000, 0x6D6FFF, "KMtronic Ltd.", "KMTRONIC" },
+	{ 0x70B3D5, 0x243000, 0x243FFF, "Rohde&Schwarz Topex SA", "ROHDE-SCHWARZ-TOPEX" },
+	{ 0x70B3D5, 0x8E0000, 0x8E0FFF, "SOUDAX EQUIPEMENTS", "SOUDAX-EQUIPEMENTS" },
+	{ 0x70B3D5, 0xFF3000, 0xFF3FFF, "Aplex Technology Inc.", "APLEX" },
+	{ 0x70B3D5, 0xBEC000, 0xBECFFF, "Tokyo Communication Equipment MFG Co.,ltd.", "TOKYO-COMMUNICATION-EQUIPMENT-MFG" },
+	{ 0x70B3D5, 0x112000, 0x112FFF, "DiTEST Fahrzeugdiagnose GmbH", "DITEST-FAHRZEUGDIAGNOSE" },
+	{ 0x70B3D5, 0x8E1000, 0x8E1FFF, "WoKa-Elektronik GmbH", "WOKA-ELEKTRONIK" },
+	{ 0x70B3D5, 0x3B8000, 0x3B8FFF, "nVideon, Inc.", "NVIDEON" },
+	{ 0x70B3D5, 0xCDE000, 0xCDEFFF, "Multipure International", "MULTIPURE" },
+	{ 0x70B3D5, 0x205000, 0x205FFF, "Esource Srl", "ESOURCE-SRL" },
+	{ 0x70B3D5, 0x502000, 0x502FFF, "Glidewell Laboratories", "GLIDEWELL-LABORATORIES" },
+	{ 0x70B3D5, 0x71E000, 0x71EFFF, "Motec Pty Ltd", "MOTEC-PTY" },
+	{ 0x70B3D5, 0x091000, 0x091FFF, "eZeLink LLC", "EZELINK-LLC" },
+	{ 0x70B3D5, 0xA6D000, 0xA6DFFF, "Metek Meteorologische Messtechnik GmbH", "METEK-METEOROLOGISCHE-MESSTECHNIK" },
+	{ 0x70B3D5, 0xEC1000, 0xEC1FFF, "Xafax Nederland bv", "XAFAX-NEDERLAND" },
+	{ 0x70B3D5, 0x0FF000, 0x0FFFFF, "INTERNET PROTOCOLO LOGICA SL", "INTERNET-PROTOCOLO-LOGICA-SL" },
+	{ 0x70B3D5, 0x7B3000, 0x7B3FFF, "BroadSoft Inc", "BROADSOFT" },
+	{ 0x70B3D5, 0x7D5000, 0x7D5FFF, "Power Dragon Development Limited", "POWER-DRAGON-DEVELOPMENT" },
+	{ 0x70B3D5, 0x0AB000, 0x0ABFFF, "KST technology", "KST" },
 
 };
