@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP.c
- * Version    : $Id: libipv6calc_db_wrapper_GeoIP.c,v 1.56 2014/05/20 17:54:47 ds6peter Exp $
+ * Version    : $Id: libipv6calc_db_wrapper_GeoIP.c,v 1.60 2014/06/22 09:49:25 ds6peter Exp $
  * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -260,29 +260,43 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 	libipv6calc_db_wrapper_GeoIPDBFileName_ptr = dl_GeoIPDBFileName_ptr;
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Assigned dlsym: %s", "GeoIPDBFileName");
 
+#else // SUPPORT_GEOIP_DYN
+
+#ifdef SUPPORT_GEOIP_LIB_VERSION
+		lib_features_GeoIP |= GEOIP_LIB_FEATURE_LIB_VERSION;
+#endif // SUPPORT_GEOIP_LIB_VERSION
+
+#if defined SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6 && defined SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6
+		lib_features_GeoIP |= (GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR | GEOIP_LIB_FEATURE_IPV6_CN_BY_ADDR);
+#else // SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6 && SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6
+#ifdef SUPPORT_GEOIP_V6
+		lib_features_GeoIP |= (GEOIP_LIB_FEATURE_IPV6_CC_BY_IPNUM | GEOIP_LIB_FEATURE_IPV6_CN_BY_IPNUM);
+#endif // SUPPORT_GEOIP_V6
+#endif // SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6 && SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6
+
+	libipv6calc_db_wrapper_GeoIPDBDescription = GeoIPDBDescription;
+	libipv6calc_db_wrapper_GeoIPDBFileName_ptr = &GeoIPDBFileName;
+	geoip_num_db_types = NUM_DB_TYPES;
+#endif // SUPPORT_GEOIP_DYN
+
 #ifdef GEOIP_WORKAROUND_NUM_DB_TYPES
 	// workaround to determine NUM_DB_TYPES until GeoIP API provides a function
 	
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Try to estimate geoip_num_db_types on dyn-load");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Try to estimate minimum geoip_num_db_types (to avoid segfaults)");
 
 	if ((lib_features_GeoIP & GEOIP_LIB_FEATURE_LIB_VERSION) != 0) {
 		geoip_num_db_types = 31 + 1; // >= 1.4.7
 	} else if ((lib_features_GeoIP & GEOIP_LIB_FEATURE_IPV6_CC_BY_IPNUM) != 0) {
 		geoip_num_db_types = 12 + 1; // >= 1.4.5
 	} else {
-		geoip_num_db_types = 11 + 1; // <= 1.45
+		geoip_num_db_types = 11 + 1; // < 1.4.5
 	};
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Estimation of geoip_num_db_types on dyn-load: %d", geoip_num_db_types - 1);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Estimation of minimum geoip_num_db_types: %d", geoip_num_db_types - 1);
 #else
-	geoip_num_db_types = 0; // FUTURE: call function
+	geoip_num_db_types = 0; // TODO: call function, once provided via GeoIP API
 #endif
 
-#else // SUPPORT_GEOIP_DYN
-	libipv6calc_db_wrapper_GeoIPDBDescription = GeoIPDBDescription;
-	libipv6calc_db_wrapper_GeoIPDBFileName_ptr = &GeoIPDBFileName;
-	geoip_num_db_types = NUM_DB_TYPES;
-#endif // SUPPORT_GEOIP_DYN
 
 	DEBUGSECTION_BEGIN(DEBUG_libipv6calc_db_wrapper_GeoIP)
 		int i;
@@ -314,17 +328,6 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 
 #else // SUPPORT_GEOIP_DYN
 
-#ifdef SUPPORT_GEOIP_LIB_VERSION
-		lib_features_GeoIP |= GEOIP_LIB_FEATURE_LIB_VERSION;
-#endif // SUPPORT_GEOIP_LIB_VERSION
-
-#if defined SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6 && defined SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6
-		lib_features_GeoIP |= (GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR | GEOIP_LIB_FEATURE_IPV6_CN_BY_ADDR);
-#else // SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6 && SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6
-#ifdef SUPPORT_GEOIP_V6
-		lib_features_GeoIP |= (GEOIP_LIB_FEATURE_IPV6_CC_BY_IPNUM | GEOIP_LIB_FEATURE_IPV6_CN_BY_IPNUM);
-#endif // SUPPORT_GEOIP_V6
-#endif // SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6 && SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6
 #endif // SUPPORT_GEOIP_DYN
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP library features: 0x%04x", lib_features_GeoIP);
@@ -343,11 +346,13 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 		wrapper_features_GeoIP |= IPV6CALC_DB_IPV4_TO_CC;
 	};
 
+#ifdef SUPPORT_GEOIP_V6
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_COUNTRY_EDITION_V6) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_COUNTRY_EDITION_V6 available");
 		geoip_country_v6 = 1;
 		wrapper_features_GeoIP |= IPV6CALC_DB_IPV6_TO_CC;
 	};
+#endif
 
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_ASNUM_EDITION) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_ASNUM_EDITION available");
@@ -356,6 +361,7 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 	};
 
 	if ((lib_features_GeoIP & (GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR | GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR)) != 0) {
+#ifdef GEOIP_ASNUM_EDITION_V6
 		if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_ASNUM_EDITION_V6) == 1) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_ASNUM_EDITION_V6 available");
 			geoip_asnum_v6 = 1;
@@ -366,6 +372,7 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_CITY_EDITION_REV1_V6 available");
 			geoip_city_v6 = 1;
 		};
+#endif
 	};
 
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_CITY_EDITION_REV1) == 1) {
@@ -454,9 +461,13 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 			if (gi == NULL) {
 				if (i == GEOIP_CITY_EDITION_REV0) { continue; };
 
-#ifdef SUPPORT_GEOIP_LIB_VERSION // >= 1.4.7
+#ifdef GEOIP_LARGE_COUNTRY_EDITION
 				if (i == GEOIP_LARGE_COUNTRY_EDITION) { continue; };
+#endif
+#ifdef GEOIP_CITY_EDITION_REV0_V6
 				if (i == GEOIP_CITY_EDITION_REV0_V6) { continue; };
+#endif
+#ifdef GEOIP_LARGE_COUNTRY_EDITION_V6
 				if (i == GEOIP_LARGE_COUNTRY_EDITION_V6) { continue; };
 #endif
 
@@ -684,7 +695,7 @@ END_libipv6calc_db_wrapper:
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Returned from libipv6calc_db_wrapper_GeoIP_db_avail with result: %d", r);
 
 	DEBUGSECTION_BEGIN(DEBUG_libipv6calc_db_wrapper_GeoIP)
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "List now available GeoIPDBFilename Entries (max:%d)", geoip_num_db_types - 1);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "List now available GeoIPDBFilename Entries (max: %d)", geoip_num_db_types - 1);
 
 		if (geoip_num_db_types > 0) {
 			int i;
@@ -1254,7 +1265,7 @@ END_libipv6calc_db_wrapper:
 #endif
 };
 
-
+#ifdef SUPPORT_GEOIP_V6
 /*
  * wrapper: GeoIP_record_by_addr_v6
  */
@@ -1307,6 +1318,7 @@ END_libipv6calc_db_wrapper:
 	return(GeoIP_record_by_addr_v6(gi, addr));
 #endif
 };
+#endif
 
 
 /*
@@ -1427,6 +1439,8 @@ END_libipv6calc_db_wrapper:
 };
 
 
+#ifdef SUPPORT_GEOIP_V6
+
 /*
  * wrapper: GeoIP_country_name_by_ipnum_v6
  */
@@ -1476,6 +1490,7 @@ END_libipv6calc_db_wrapper:
 #endif
 };
 
+#endif // SUPPORT_GEOIP_V6
 
 /*
  * wrapper: GeoIP_name_by_addr
@@ -1531,6 +1546,7 @@ END_libipv6calc_db_wrapper:
 };
 
 
+#ifdef SUPPORT_GEOIP_V6
 /*
  * wrapper: GeoIP_name_by_addr_v6
  */
@@ -1583,6 +1599,7 @@ END_libipv6calc_db_wrapper:
 	return(GeoIP_name_by_addr_v6(gi, addr));
 #endif
 };
+#endif // SUPPORT_GEOIP_V6
 
 
 /********************************************************
@@ -1820,8 +1837,10 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_code_by_addr(const char
 
 	if (proto == 4) {
 		GeoIP_type = GEOIP_COUNTRY_EDITION;
+#ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		GeoIP_type = GEOIP_COUNTRY_EDITION_V6;
+#endif // SUPPORT_GEOIP_V6
 	} else {
 		return (NULL);
 	};
@@ -1833,6 +1852,7 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_code_by_addr(const char
 
 	if (proto == 4) {
 		GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_country_code_by_addr(gi, addr);
+#ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		if ((lib_features_GeoIP & GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR) != 0) {
 			GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_country_code_by_addr_v6(gi, addr);
@@ -1847,6 +1867,7 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_code_by_addr(const char
 			};
 			GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_country_code_by_ipnum_v6(gi, ipv6addr.in6_addr);
 		};
+#endif // SUPPORT_GEOIP_V6
 	};
 
 	if (GeoIP_result_ptr == NULL) {
@@ -1877,8 +1898,10 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_name_by_addr(const char
 
 	if (proto == 4) {
 		GeoIP_type = GEOIP_COUNTRY_EDITION;
+#ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		GeoIP_type = GEOIP_COUNTRY_EDITION_V6;
+#endif // SUPPORT_GEOIP_V6
 	} else {
 		return (NULL);
 	};
@@ -1890,6 +1913,7 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_name_by_addr(const char
 
 	if (proto == 4) {
 		GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_country_name_by_addr(gi, addr);
+#ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		if ((lib_features_GeoIP & GEOIP_LIB_FEATURE_IPV6_CN_BY_ADDR) != 0) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Call libipv6calc_db_wrapper_GeoIP_country_name_by_addr_v6");
@@ -1906,11 +1930,14 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_name_by_addr(const char
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Call libipv6calc_db_wrapper_GeoIP_country_name_by_ipnum");
 			GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_country_name_by_ipnum_v6(gi, ipv6addr.in6_addr);
 		};
+#endif // SUPPORT_GEOIP_V6
 	};
 
 	GEOIP_DB_USAGE_MAP_TAG(GeoIP_type);
 
+#ifdef SUPPORT_GEOIP_V6
 END_libipv6calc_db_wrapper:
+#endif // SUPPORT_GEOIP_V6
 	libipv6calc_db_wrapper_GeoIP_delete(gi);
 
 	return(GeoIP_result_ptr);
@@ -1931,18 +1958,26 @@ char *libipv6calc_db_wrapper_GeoIP_wrapper_asnum_by_addr(const char *addr, const
 			return(NULL);
 		};
 
-		/* TODO: workaround in case of old headerfile is used */
+#ifdef GEOIP_ASNUM_EDITION
 		GeoIP_type = GEOIP_ASNUM_EDITION;
+#else
+		return(NULL);
+#endif
 
+#ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		if ((wrapper_features_GeoIP & IPV6CALC_DB_IPV6_TO_AS) == 0) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Database/Support not available: GEOIP_ASNUM_EDITION_V6");
 			return(NULL);
 		};
 
-		/* TODO: workaround in case of old headerfile is used */
+#ifdef GEOIP_ASNUM_EDITION_V6
 		GeoIP_type = GEOIP_ASNUM_EDITION_V6;
+#else
+		return(NULL);
+#endif
 
+#endif // SUPPORT_GEOIP_V6
 	} else {
 		return(NULL);
 	};
@@ -1954,8 +1989,10 @@ char *libipv6calc_db_wrapper_GeoIP_wrapper_asnum_by_addr(const char *addr, const
 
 	if (proto == 4) {
 		GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_name_by_addr(gi, addr);
+#ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_name_by_addr_v6(gi, addr);
+#endif // SUPPORT_GEOIP_V6
 	};
 
 	if (GeoIP_result_ptr == NULL) {
@@ -1981,10 +2018,16 @@ GeoIPRecord *libipv6calc_db_wrapper_GeoIP_wrapper_record_city_by_addr(const char
 
 	if (proto == 4) {
 		GeoIP_type = GEOIP_CITY_EDITION_REV1;
+#ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		if ((lib_features_GeoIP & GEOIP_LIB_FEATURE_LIB_VERSION) != 0) {
+#ifdef GEOIP_CITY_EDITION_REV1_V6
 			GeoIP_type = GEOIP_CITY_EDITION_REV1_V6;
+#else
+			return (NULL);
+#endif
 		};
+#endif // SUPPORT_GEOIP_V6
 	} else {
 		return (NULL);
 	};
@@ -1996,8 +2039,10 @@ GeoIPRecord *libipv6calc_db_wrapper_GeoIP_wrapper_record_city_by_addr(const char
 
 	if (proto == 4) {
 		GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_record_by_addr(gi, addr);
+#ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
 		GeoIP_result_ptr = libipv6calc_db_wrapper_GeoIP_record_by_addr_v6(gi, addr);
+#endif // SUPPORT_GEOIP_V6
 	};
 
 	if (GeoIP_result_ptr == NULL) {
