@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc/logstats
 # File       : test_ipv6logstats.sh
-# Version    : $Id: test_ipv6logstats.sh,v 1.16 2014/05/20 17:54:47 ds6peter Exp $
+# Version    : $Id: test_ipv6logstats.sh,v 1.17 2014/06/26 05:49:27 ds6peter Exp $
 # Copyright  : 2003-2014 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test program for "ipv6logstats"
@@ -131,7 +131,7 @@ fi
 echo
 
 #testscenarios version 3
-if ./ipv6logstats -v 2>&1 | grep -w "STAT_CC"; then
+if ./ipv6logstats -v 2>&1 | grep -qw "STAT_CC"; then
 	testscenarios | ./ipv6logstats -q | grep -q '\*3\*CC-proto-code-list/ALL'
 	retval=$?
 	if [ $retval -ne 0 ]; then
@@ -143,11 +143,11 @@ else
 fi
 
 # testscenarios matching
-if ./ipv6logstats -v 2>&1 | grep -w "STAT_CC"; then
+if ./ipv6logstats -v 2>&1 | grep -qw "STAT_CC"; then
 	feature_cc=1
 fi
 
-if ./ipv6logstats -v 2>&1 | grep -w "STAT_AS"; then
+if ./ipv6logstats -v 2>&1 | grep -qw "STAT_AS"; then
 	feature_as=1
 fi
 
